#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 easy-file
version:              0.2.5
visibility:           public
id:                   easy-file-0.2.5-7ZeeNQNhxBXBlSKMcMobf0
key:                  easy-file-0.2.5-7ZeeNQNhxBXBlSKMcMobf0
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://github.com/kazu-yamamoto/easy-file
synopsis:             Cross-platform File handling
description:          Cross-platform File handling for Unix\/Mac\/Windows
category:             System
abi:                  0430fc58fed1d896b2e3c31be44a7128
exposed:              True
exposed-modules:      System.EasyFile
hidden-modules:
    System.EasyFile.FilePath System.EasyFile.Directory
    System.EasyFile.Missing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/easy-file-0.2.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/easy-file-0.2.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/easy-file-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-easy-file
hs-libraries:         HSeasy-file-0.2.5-7ZeeNQNhxBXBlSKMcMobf0
depends:
    base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1 time-1.12.2
    unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-easy-file/html/easy-file.haddock
haddock-html:         /usr/share/doc/haskell-easy-file/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

